/* GNOME Panel Widget
 * Copyright (C) 1999 Kevin Fox
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gdk/gdkx.h>
#include <gtk/gtk.h>
#include <gnome.h>
#include "gnome-panel.h"

GtkWidget *dock;

gint gnome_applet_spot_remove(GtkWidget *widget, gpointer gdata){
  GtkWidget *socket=(GtkWidget *)gdata;
  GtkWidget *dockitem;
  dockitem=gtk_object_get_data(GTK_OBJECT(socket), "dockitem");
  gtk_object_destroy(GTK_OBJECT(dockitem));
  g_print("blar\n");
  return FALSE;
}

gint32 gnome_applet_spot_add(GtkWidget *dock){
  GtkWidget *socket;
  GtkWidget *dockitem;
  socket = gtk_socket_new();
  dockitem = gnome_dock_item_new ("dockitem", GNOME_DOCK_ITEM_BEH_NORMAL);
  gtk_object_set_data (GTK_OBJECT (socket), "dockitem", dockitem);
  gnome_dock_add_item(GNOME_DOCK(dock), GNOME_DOCK_ITEM(dockitem), GNOME_DOCK_TOP, 0, 0, 0, FALSE);
  gtk_container_add (GTK_CONTAINER (dockitem), socket);
  gtk_widget_realize (socket);
  gtk_widget_show (dockitem);
  gtk_widget_show(socket);
  gtk_signal_connect(GTK_OBJECT(socket), "destroy", GTK_SIGNAL_FUNC(gnome_applet_spot_remove), socket);
  g_print ("The XID of the sockets window is %x\n",GDK_WINDOW_XWINDOW (socket->window));
  g_print ("%x\n",GDK_WINDOW_XWINDOW (socket->window));
  return((gint32)GDK_WINDOW_XWINDOW(socket->window));
}


/*** App-specific servant structures ***/
typedef struct {
POA_GNOME_panel servant;
PortableServer_POA poa;

} impl_POA_GNOME_panel;




/*** Implementation stub prototypes ***/
static void impl_GNOME_panel__destroy(impl_POA_GNOME_panel *servant,
CORBA_Environment *ev);
static CORBA_long
impl_GNOME_panel_new_spot(impl_POA_GNOME_panel *servant,
CORBA_Environment *ev);




/*** epv structures ***/
static PortableServer_ServantBase__epv impl_GNOME_panel_base_epv = {
NULL, /* _private data */
NULL, /* finalize routine */
NULL, /* default_POA routine */
};
static POA_GNOME_panel__epv impl_GNOME_panel_epv = {
NULL, /* _private */
(gpointer)&impl_GNOME_panel_new_spot,

};


/*** vepv structures ***/
static POA_GNOME_panel__vepv impl_GNOME_panel_vepv = {
&impl_GNOME_panel_base_epv,
&impl_GNOME_panel_epv,
};


/*** Stub implementations ***/
static GNOME_panel impl_GNOME_panel__create(PortableServer_POA poa, CORBA_Environment *ev)
{
GNOME_panel retval;
impl_POA_GNOME_panel *newservant;
PortableServer_ObjectId *objid;

newservant = g_new0(impl_POA_GNOME_panel, 1);
newservant->servant.vepv = &impl_GNOME_panel_vepv;
newservant->poa = poa;
POA_GNOME_panel__init((PortableServer_Servant)newservant, ev);
objid = PortableServer_POA_activate_object(poa, newservant, ev);
CORBA_free(objid);
retval = PortableServer_POA_servant_to_reference(poa, newservant, ev);

return retval;
}

static void
impl_GNOME_panel__destroy(impl_POA_GNOME_panel *servant, CORBA_Environment *ev)
{
PortableServer_ObjectId *objid;

objid = PortableServer_POA_servant_to_id(servant->poa, servant, ev);
PortableServer_POA_deactivate_object(servant->poa, objid, ev);
CORBA_free(objid);

POA_GNOME_panel__fini((PortableServer_Servant)servant, ev);
g_free(servant);
}

static CORBA_long
impl_GNOME_panel_new_spot(impl_POA_GNOME_panel *servant,
CORBA_Environment *ev)
{
CORBA_long retval;
retval=gnome_applet_spot_add(dock);
g_print("Returning %x\n", retval);
return retval;
}

GtkWidget *gnome_panel_widget_new(){
  GtkWidget *socket;
  GtkWidget *dockitem;
  CORBA_Environment ev;
  PortableServer_POA poa;
  CORBA_ORB orb;
  GNOME_panel panel_server;
  char *stringified_reference;

  CORBA_exception_init(&ev);
  orb=gnome_CORBA_ORB();
  poa = (PortableServer_POA)CORBA_ORB_resolve_initial_references(orb, "RootPOA", &ev);
  PortableServer_POAManager_activate(PortableServer_POA__get_the_POAManager(poa, &ev), &ev); 
  panel_server = impl_GNOME_panel__create(poa, &ev);
  stringified_reference = CORBA_ORB_object_to_string(orb, panel_server, &ev);
  g_print("My %s\n", stringified_reference);

  dock = gnome_dock_new ();
  return dock;
}



